# This module is automatically created from setup.py
git_sha1 = None
local_modifications = None
version = '2024.2'
long_version = 'pyrockoeost-2024.2-2024-07-04_12:30:20'  # noqa
installed_date = '2024-07-04_12:30:20'
src_path = '/home/user/Music/pyrockoeost'
